@@ -13,6 +13,7 @@ from pykechain.models.widgets.widget_schemas import undefined_meta_schema
 # TASKNAVIGATIONBAR = 'TASKNAVIGATIONBAR'
 # JSON = 'JSON'
 # METAPANEL = 'METAPANEL'
+# FORMMETAPANEL = 'FORMMETAPANEL'
 # MULTICOLUMN = 'MULTICOLUMN'
 # SCOPE_WIDGET = 'SCOPE_WIDGET'
 # THIRD_PARTY = 'THIRD_PARTY'
@@ -28,6 +29,10 @@ class MetapanelWidget(Widget):
     """Metapanel Widget."""
 
 
+class FormmetapanelWidget(Widget):
+    """FormMetapanel Widget."""
+
+
 class PropertygridWidget(Widget):
     """Propertygrid Widget."""
 
