@@ -1,123 +1,136 @@
-from jsonschema import validate, ValidationError
+from unittest import TestCase
 
-from pykechain.enums import PropertyVTypes, PropertyType
+from jsonschema import ValidationError, validate
+
+from pykechain.enums import PropertyType, PropertyVTypes
 from pykechain.exceptions import IllegalArgumentError
-from pykechain.models import Property, AttachmentProperty
-from pykechain.models.validators import PropertyValidator, ValidatorEffect, VisualEffect, ValidVisualEffect, \
-    InvalidVisualEffect, NumericRangeValidator, BooleanFieldValidator
-from pykechain.models.validators.validator_schemas import options_json_schema, validator_jsonschema_stub, \
-    effects_jsonschema_stub
-from pykechain.models.validators.validators import RegexStringValidator, RequiredFieldValidator, EvenNumberValidator, \
-    OddNumberValidator, SingleReferenceValidator, EmailValidator, AlwaysAllowValidator, FileSizeValidator, \
-    FileExtensionValidator
-from tests.classes import SixTestCase, TestBetamax
+from pykechain.models import AttachmentProperty, Property
+from pykechain.models.validators import (
+    BooleanFieldValidator,
+    InvalidVisualEffect,
+    NumericRangeValidator,
+    PropertyValidator,
+    ValidVisualEffect,
+    ValidatorEffect,
+    VisualEffect,
+)
+from pykechain.models.validators.validator_schemas import (
+    effects_jsonschema_stub,
+    options_json_schema,
+    validator_jsonschema_stub,
+)
+from pykechain.models.validators.validators import (
+    AlwaysAllowValidator,
+    EmailValidator,
+    EvenNumberValidator,
+    FileExtensionValidator,
+    FileSizeValidator,
+    OddNumberValidator,
+    RegexStringValidator,
+    RequiredFieldValidator,
+    SingleReferenceValidator,
+)
+from tests.classes import TestBetamax
 
 
-class TestValidatorJSON(SixTestCase):
+class TestValidatorJSON(TestCase):
     def test_valid_numeric_range_validator_json(self):
         options = dict(
-            validators=[dict(
-                vtype='numericRangeValidator',
-                config=dict(
-                    minvalue=2,
-                    maxvalue=10,
-                    stepsize=2,
-                    on_valid=[dict(effect="CssEffect", config=dict(applyCss="valid"))],
-                    on_invalid=[dict(effect="CssEffect", config=dict(applyCss="invalid")),
-                                dict(effect="ErrorText",
-                                     config=dict(text="Range should be between 2 and 10 with step 2."))]
+            validators=[
+                dict(
+                    vtype="numericRangeValidator",
+                    config=dict(
+                        minvalue=2,
+                        maxvalue=10,
+                        stepsize=2,
+                        on_valid=[dict(effect="CssEffect", config=dict(applyCss="valid"))],
+                        on_invalid=[
+                            dict(effect="CssEffect", config=dict(applyCss="invalid")),
+                            dict(
+                                effect="ErrorText",
+                                config=dict(text="Range should be between 2 and 10 with step 2."),
+                            ),
+                        ],
+                    ),
                 )
-            )]
+            ]
         )
 
         validate(options_json_schema, options)
 
     def test_valid_requiredfield_validator_json(self):
-        options = {'validators': [
-            {
-                'vtype': 'requiredFieldValidator',
-                'config': {
-                    'effects_when_valid': [],
-                    'effects_when_invalid': [{'effect': "ErrorText", 'config': {'Text': "This field is required."}}]
-                }
-            }, {
-                'vtype': 'numericRangeValidator',
-                'config': {'minValue': 0}
-            }
-        ]}
+        options = {
+            "validators": [
+                {
+                    "vtype": "requiredFieldValidator",
+                    "config": {
+                        "effects_when_valid": [],
+                        "effects_when_invalid": [
+                            {"effect": "ErrorText", "config": {"Text": "This field is required."}}
+                        ],
+                    },
+                },
+                {"vtype": "numericRangeValidator", "config": {"minValue": 0}},
+            ]
+        }
 
         validate(options_json_schema, options)
 
     def test_valid_booleanfield_validator_json(self):
-        options = {'validators': [{
-            'vtype': 'booleanFieldValidator',
-            'config': {
-                'is_valid': False,
-                'is_invalid': [True, None],
-                'effects_when_valid': [],
-                'effects_when_invalid': [{'effect': 'ErrorText', 'text': 'Value of the field should be False'}]}
-        }]}
+        options = {
+            "validators": [
+                {
+                    "vtype": "booleanFieldValidator",
+                    "config": {
+                        "is_valid": False,
+                        "is_invalid": [True, None],
+                        "effects_when_valid": [],
+                        "effects_when_invalid": [
+                            {"effect": "ErrorText", "text": "Value of the field should be False"}
+                        ],
+                    },
+                }
+            ]
+        }
 
         validate(options_json_schema, options)
 
     def test_validator_invalid_vtype(self):
-        validator_json = {
-            'vtype': 'invalid',
-            'config': {}
-        }
+        validator_json = {"vtype": "invalid", "config": {}}
         with self.assertRaisesRegex(ValidationError, "'invalid' is not one of"):
             validate(validator_json, validator_jsonschema_stub)
 
     def test_validator_missing_vtype(self):
-        validator_json = {
-            'config': {}
-        }
+        validator_json = {"config": {}}
         with self.assertRaisesRegex(ValidationError, "'vtype' is a required property"):
             validate(validator_json, validator_jsonschema_stub)
 
     def test_validator_config_not_a_dict(self):
-        v = {
-            'vtype': PropertyVTypes.NUMERICRANGE,
-            'config': []
-        }
+        v = {"vtype": PropertyVTypes.NUMERICRANGE, "config": []}
         with self.assertRaisesRegex(ValidationError, "is not of type 'object'"):
             validate(v, validator_jsonschema_stub)
 
     def test_validator_on_valid_not_a_list(self):
-        v = {
-            'vtype': PropertyVTypes.NUMERICRANGE,
-            'config': {
-                'on_valid': {}
-            }
-        }
+        v = {"vtype": PropertyVTypes.NUMERICRANGE, "config": {"on_valid": {}}}
         with self.assertRaisesRegex(ValidationError, "is not of type 'array'"):
             validate(v, validator_jsonschema_stub)
 
     def test_validator_on_invalid_not_a_list(self):
-        v = {
-            'vtype': PropertyVTypes.NUMERICRANGE,
-            'config': {
-                'on_invalid': {}
-            }
-        }
+        v = {"vtype": PropertyVTypes.NUMERICRANGE, "config": {"on_invalid": {}}}
         with self.assertRaisesRegex(ValidationError, "is not of type 'array'"):
             validate(v, validator_jsonschema_stub)
 
     def test_validator_on_valid_list_with_obj(self):
         v = {
-            'vtype': PropertyVTypes.NUMERICRANGE,
-            'config': {
-                'on_valid': [{'effect': '', 'config': {}}]
-            }
+            "vtype": PropertyVTypes.NUMERICRANGE,
+            "config": {"on_valid": [{"effect": "", "config": {}}]},
         }
         validate(v, validator_jsonschema_stub)
 
     def test_validator_on_invalid_list_with_obj(self):
         v = {
-            'vtype': PropertyVTypes.NUMERICRANGE,
-            'config': {
-                'on_invalid': [{'effect': '', 'config': {}}]
-            }
+            "vtype": PropertyVTypes.NUMERICRANGE,
+            "config": {"on_invalid": [{"effect": "", "config": {}}]},
         }
         validate(v, validator_jsonschema_stub)
 
@@ -127,64 +140,64 @@ class TestValidatorJSON(SixTestCase):
             validate(v, effects_jsonschema_stub)
 
     def test_validatoreffect_requires_config_property(self):
-        v = {'effect': ''}
+        v = {"effect": ""}
         with self.assertRaisesRegex(ValidationError, "'config' is a required property"):
             validate(v, effects_jsonschema_stub)
 
     def test_validatoreffect_not_allows_additional_properties(self):
-        v = {
-            'effect': '',
-            'config': {},
-            'additional_option': None
-
-        }
-        with self.assertRaisesRegex(ValidationError,
-                                    r"Additional properties are not allowed \('additional_option' was unexpected\)"):
+        v = {"effect": "", "config": {}, "additional_option": None}
+        with self.assertRaisesRegex(
+            ValidationError,
+            r"Additional properties are not allowed \('additional_option' was unexpected\)",
+        ):
             validate(v, effects_jsonschema_stub)
 
 
-class TestPropertyValidatorClass(SixTestCase):
+class TestPropertyValidatorClass(TestCase):
     def test_propertyvalidator_produces_valid_json(self):
         pv = PropertyValidator()
         pv.validate_json()
 
 
-class TestValidatorEffects(SixTestCase):
+class TestValidatorEffects(TestCase):
     def test_validator_effect_produces_valid_json(self):
         ve = ValidatorEffect()
         ve.validate_json()
 
     def test_visual_effect_produces_valid_json(self):
         ve = VisualEffect()
-        self.assertTrue('applyCss' in ve.as_json().get('config'))
+        self.assertTrue("applyCss" in ve.as_json().get("config"))
         ve.validate_json()
 
     def test_valid_visualeffect_produces_valid_json(self):
         ve = ValidVisualEffect()
-        self.assertTrue('applyCss' in ve.as_json().get('config'))
+        self.assertTrue("applyCss" in ve.as_json().get("config"))
         ve.validate_json()
 
     def test_invalid_visualeffect_productes_valid_json(self):
         ve = InvalidVisualEffect()
-        self.assertTrue('applyCss' in ve.as_json().get('config'))
+        self.assertTrue("applyCss" in ve.as_json().get("config"))
         ve.validate_json()
 
 
-class TestValidatorParsing(SixTestCase):
-
+class TestValidatorParsing(TestCase):
     def test_valid_numeric_range_validator_json(self):
         validator_json = dict(
-            vtype='numericRangeValidator',
+            vtype="numericRangeValidator",
             config=dict(
                 minvalue=2,
                 maxvalue=10,
                 stepsize=2,
                 enforce_stepsize=False,
                 on_valid=[dict(effect="visualEffect", config=dict(applyCss="valid"))],
-                on_invalid=[dict(effect="visualEffect", config=dict(applyCss="invalid")),
-                            dict(effect="errorTextEffect",
-                                 config=dict(text="Range should be between 2 and 10 with step 2."))]
-            )
+                on_invalid=[
+                    dict(effect="visualEffect", config=dict(applyCss="invalid")),
+                    dict(
+                        effect="errorTextEffect",
+                        config=dict(text="Range should be between 2 and 10 with step 2."),
+                    ),
+                ],
+            ),
         )
 
         validator = PropertyValidator.parse(validator_json)
@@ -194,21 +207,24 @@ class TestValidatorParsing(SixTestCase):
         pass
 
 
-class TestValidatorDumping(SixTestCase):
-
+class TestValidatorDumping(TestCase):
     def test_valid_numeric_range_validator_dumped(self):
         validator_json = dict(
-            vtype='numericRangeValidator',
+            vtype="numericRangeValidator",
             config=dict(
                 minvalue=2,
                 maxvalue=10,
                 stepsize=2,
                 enforce_stepsize=False,
                 on_valid=[dict(effect="visualEffect", config=dict(applyCss="valid"))],
-                on_invalid=[dict(effect="visualEffect", config=dict(applyCss="invalid")),
-                            dict(effect="errorTextEffect",
-                                 config=dict(text="Range should be between 2 and 10 with step 2."))]
-            )
+                on_invalid=[
+                    dict(effect="visualEffect", config=dict(applyCss="invalid")),
+                    dict(
+                        effect="errorTextEffect",
+                        config=dict(text="Range should be between 2 and 10 with step 2."),
+                    ),
+                ],
+            ),
         )
 
         validator = PropertyValidator.parse(validator_json)
@@ -219,14 +235,14 @@ class TestValidatorDumping(SixTestCase):
         self.assertIsNone(validator.validate_json())
 
 
-class TestNumericRangeValidator(SixTestCase):
+class TestNumericRangeValidator(TestCase):
     def test_numeric_range_without_settings_validated_json(self):
         validator = NumericRangeValidator()
 
         as_json = validator.as_json()
         self.assertIsNone(validator.validate_json())
         self.assertIsInstance(as_json, dict)
-        self.assertDictEqual(as_json, {'config': {}, 'vtype': 'numericRangeValidator'})
+        self.assertDictEqual(as_json, {"config": {}, "vtype": "numericRangeValidator"})
 
     def test_numeric_range_validates_with_lower_bound(self):
         validator = NumericRangeValidator(minvalue=0)
@@ -261,7 +277,7 @@ class TestNumericRangeValidator(SixTestCase):
         self.assertFalse(validator.is_valid(-1))
 
     def test_numeric_range_validates_with_min_max_bound_float(self):
-        validator = NumericRangeValidator(maxvalue=10., minvalue=0.)
+        validator = NumericRangeValidator(maxvalue=10.0, minvalue=0.0)
         self.assertTrue(validator.is_valid(1.5))
 
     def test_numeric_range_validates_with_stepsize_float(self):
@@ -275,11 +291,13 @@ class TestNumericRangeValidator(SixTestCase):
         self.assertTrue(validator.is_invalid(16))
 
     def test_numeric_range_raises_exception_when_min_is_greater_than_max(self):
-        with self.assertRaisesRegex(Exception, 'should be smaller than the maxvalue'):
+        with self.assertRaisesRegex(Exception, "should be smaller than the maxvalue"):
             NumericRangeValidator(minvalue=11, maxvalue=-11)
 
     def test_numeric_range_raises_exception_when_enforce_stepsize_without_stepsize(self):
-        with self.assertRaisesRegex(Exception, 'The stepsize should be provided when enforcing stepsize'):
+        with self.assertRaisesRegex(
+            Exception, "The stepsize should be provided when enforcing stepsize"
+        ):
             NumericRangeValidator(stepsize=None, enforce_stepsize=True)
 
     def test_numeric_range_does_not_respect_max_issue_435(self):
@@ -294,25 +312,27 @@ class TestNumericRangeValidator(SixTestCase):
         self.assertRegex(validator.get_reason(), "Value '3333' should be between -inf and 1000")
 
 
-class TestBooleanFieldValidator(SixTestCase):
+class TestBooleanFieldValidator(TestCase):
     def test_boolean_validator_without_settings(self):
         validator = BooleanFieldValidator()
         self.assertIsNone(validator.validate_json())
         self.assertIsInstance(validator.as_json(), dict)
-        self.assertDictEqual(validator.as_json(), {'config': {}, 'vtype': 'booleanFieldValidator'})
+        self.assertDictEqual(validator.as_json(), {"config": {}, "vtype": "booleanFieldValidator"})
 
 
-class TestRequiredFieldValidator(SixTestCase):
+class TestRequiredFieldValidator(TestCase):
     def test_requiredfield_validator_without_settings(self):
         validator = RequiredFieldValidator()
         self.assertIsNone(validator.validate_json())
         self.assertIsInstance(validator.as_json(), dict)
-        self.assertDictEqual(validator.as_json(), {'config': {}, 'vtype': 'requiredFieldValidator'})
+        self.assertDictEqual(
+            validator.as_json(), {"config": {}, "vtype": "requiredFieldValidator"}
+        )
 
     def test_requiredfield_validator_is_false_on_nonevalue(self):
         validator = RequiredFieldValidator()
         self.assertFalse(validator.is_valid(None))
-        self.assertFalse(validator.is_valid(''))
+        self.assertFalse(validator.is_valid(""))
         self.assertFalse(validator.is_valid([]))
         self.assertFalse(validator.is_valid(list()))
         self.assertFalse(validator.is_valid(tuple()))
@@ -326,61 +346,61 @@ class TestRequiredFieldValidator(SixTestCase):
         self.assertTrue(validator.is_valid(1))
         self.assertTrue(validator.is_valid(0))
         self.assertTrue(validator.is_valid(0.0))
-        self.assertTrue(validator.is_valid(float('inf')))
-        self.assertTrue(validator.is_valid('string'))
-        self.assertTrue(validator.is_valid({'key': 'val'}))
+        self.assertTrue(validator.is_valid(float("inf")))
+        self.assertTrue(validator.is_valid("string"))
+        self.assertTrue(validator.is_valid({"key": "val"}))
         self.assertTrue(validator.is_valid([1, 2, 3]))
         self.assertTrue(validator.is_valid((1,)))
         self.assertTrue(validator.is_valid({1, 2, 3}))
         self.assertTrue(validator.is_valid(False))
 
 
-class TestRegexValidator(SixTestCase):
+class TestRegexValidator(TestCase):
     def test_regex_validator_without_settings(self):
         validator = RegexStringValidator()
         self.assertIsNone(validator.validate_json())
         self.assertIsInstance(validator.as_json(), dict)
-        self.assertDictEqual(validator.as_json(), {'config': {}, 'vtype': 'regexStringValidator'})
+        self.assertDictEqual(validator.as_json(), {"config": {}, "vtype": "regexStringValidator"})
 
     def test_regex_validator_with_pattern_match(self):
-        validator = RegexStringValidator(pattern=r'.*')
+        validator = RegexStringValidator(pattern=r".*")
 
-        self.assertTrue(validator('mr cactus is tevree'))
+        self.assertTrue(validator("mr cactus is tevree"))
 
     def test_regex_validator_without_pattern_match(self):
         validator = RegexStringValidator()
 
         # per default the regex string matches everything
-        self.assertEqual(validator.pattern, '.+')
-        self.assertTrue(validator('mr cactus is tevree'))
-        self.assertFalse(validator(''))
+        self.assertEqual(validator.pattern, ".+")
+        self.assertTrue(validator("mr cactus is tevree"))
+        self.assertFalse(validator(""))
 
     def test_regex_validator_fails_on_none_value(self):
-        validator = RegexStringValidator(pattern=r'.*')
+        validator = RegexStringValidator(pattern=r".*")
 
         self.assertFalse(validator.is_valid(None))
 
     def test_regex_validator_complex_email_regex(self):
         validator = EmailValidator()
 
-        self.assertTrue(validator.is_valid('support@ke-works.com'))
-        self.assertFalse(validator.is_valid('___'))
+        self.assertTrue(validator.is_valid("support@ke-works.com"))
+        self.assertFalse(validator.is_valid("___"))
         self.assertIsNone(validator.is_valid(None))
-        self.assertFalse(validator.is_valid('user@domain'))
+        self.assertFalse(validator.is_valid("user@domain"))
 
 
-class TestOddEvenNumberValidator(SixTestCase):
+class TestOddEvenNumberValidator(TestCase):
     def test_even_number_validator_without_settings(self):
         validator = EvenNumberValidator()
         self.assertIsNone(validator.validate_json())
         self.assertIsInstance(validator.as_json(), dict)
-        self.assertDictEqual(validator.as_json(), {'config': {}, 'vtype': 'evenNumberValidator'})
+        self.assertDictEqual(validator.as_json(), {"config": {}, "vtype": "evenNumberValidator"})
 
     def test_odd_number_validator_without_settings(self):
         validator = OddNumberValidator()
         self.assertIsNone(validator.validate_json())
         self.assertIsInstance(validator.as_json(), dict)
-        self.assertDictEqual(validator.as_json(), {'config': {}, 'vtype': 'oddNumberValidator'})
+        self.assertDictEqual(validator.as_json(), {"config": {}, "vtype": "oddNumberValidator"})
 
     def test_even_number_validator_is_valid(self):
         validator = EvenNumberValidator()
@@ -444,12 +464,14 @@ class TestOddEvenNumberValidator(SixTestCase):
         self.assertFalse(validator.is_valid("3"))
 
 
-class TestSingleReferenceValidator(SixTestCase):
+class TestSingleReferenceValidator(TestCase):
     def test_singlereference_validator_without_settings(self):
         validator = SingleReferenceValidator()
         self.assertIsNone(validator.validate_json())
         self.assertIsInstance(validator.as_json(), dict)
-        self.assertDictEqual(validator.as_json(), {'config': {}, 'vtype': 'singleReferenceValidator'})
+        self.assertDictEqual(
+            validator.as_json(), {"config": {}, "vtype": "singleReferenceValidator"}
+        )
 
     def test_singlereference_validator_is_valid(self):
         validator = SingleReferenceValidator()
@@ -457,7 +479,7 @@ class TestSingleReferenceValidator(SixTestCase):
         self.assertTrue(validator.is_valid(list()))
         self.assertTrue(validator.is_valid(set()))
         self.assertTrue(validator.is_valid(tuple()))
-        self.assertTrue(validator.is_valid(('first selection',)))
+        self.assertTrue(validator.is_valid(("first selection",)))
 
     def test_singlereference_validator_is_invalid(self):
         validator = SingleReferenceValidator()
@@ -471,13 +493,13 @@ class TestSingleReferenceValidator(SixTestCase):
         self.assertFalse(validator.is_valid(dict()))
 
 
-class TestAlwaysAllowValidator(SixTestCase):
+class TestAlwaysAllowValidator(TestCase):
     def test_always_allow_validator_without_settings(self):
         validator = AlwaysAllowValidator()
-        self.assertTrue(validator.is_valid('some text'))
+        self.assertTrue(validator.is_valid("some text"))
         self.assertTrue(validator.is_valid(42))
         self.assertTrue(validator.is_valid(42.0))
-        self.assertTrue(validator.is_valid(['a', 'b']))
+        self.assertTrue(validator.is_valid(["a", "b"]))
         self.assertTrue(validator.is_valid(True))
         self.assertTrue(validator.is_valid(False))
         self.assertTrue(validator.is_valid(None))
@@ -489,7 +511,7 @@ class TestAlwaysAllowValidator(SixTestCase):
         self.assertIsNone(validator.validate_json())
 
 
-class TestFileSizeValidator(SixTestCase):
+class TestFileSizeValidator(TestCase):
     def test_validator_valid_json_with_settings(self):
         validator = FileSizeValidator(max_size=100)
         self.assertIsNone(validator.validate_json())
@@ -506,28 +528,28 @@ class TestFileSizeValidator(SixTestCase):
 
     # noinspection PyTypeChecker
     def test_validator_invalid_arguments(self):
-        with self.assertRaisesRegex(ValueError, 'should be a number'):
+        with self.assertRaisesRegex(ValueError, "should be a number"):
             FileSizeValidator(max_size=set())
-        with self.assertRaisesRegex(ValueError, 'should be a number'):
+        with self.assertRaisesRegex(ValueError, "should be a number"):
             FileSizeValidator(max_size=list())
-        with self.assertRaisesRegex(ValueError, 'should be a number'):
+        with self.assertRaisesRegex(ValueError, "should be a number"):
             FileSizeValidator(max_size=dict())
-        with self.assertRaisesRegex(ValueError, 'should be a number'):
+        with self.assertRaisesRegex(ValueError, "should be a number"):
             FileSizeValidator(max_size=tuple())
-        with self.assertRaisesRegex(ValueError, 'should be a number'):
+        with self.assertRaisesRegex(ValueError, "should be a number"):
             FileSizeValidator(max_size=tuple())
-        with self.assertRaisesRegex(ValueError, 'should be a number'):
-            FileSizeValidator(max_size='100')
+        with self.assertRaisesRegex(ValueError, "should be a number"):
+            FileSizeValidator(max_size="100")
 
     def test_filesizevalidator_being_valid(self):
         validator = FileSizeValidator(max_size=100)
 
         self.assertTrue(validator.is_valid(100))
-        self.assertTrue(validator.is_valid(100.))
+        self.assertTrue(validator.is_valid(100.0))
         self.assertTrue(validator.is_valid(99))
         self.assertTrue(validator.is_valid(0))
 
-        self.assertTrue(validator.is_valid('text'))
+        self.assertTrue(validator.is_valid("text"))
         self.assertTrue(validator.is_valid(list()))
         self.assertTrue(validator.is_valid(tuple()))
         self.assertTrue(validator.is_valid(dict()))
@@ -537,7 +559,7 @@ class TestFileSizeValidator(SixTestCase):
         validator = FileSizeValidator(max_size=100)
 
         self.assertFalse(validator.is_valid(101))
-        self.assertFalse(validator.is_valid(101.))
+        self.assertFalse(validator.is_valid(101.0))
         self.assertFalse(validator.is_valid(-1))
 
     def test_filesizevalidator_being_none(self):
@@ -546,7 +568,7 @@ class TestFileSizeValidator(SixTestCase):
         self.assertIsNone(validator.is_valid(None))
 
 
-class TestFileExtensionValidator(SixTestCase):
+class TestFileExtensionValidator(TestCase):
     def test_validator_valid_json_with_settings(self):
         validator = FileExtensionValidator(accept=[".csv"])
         self.assertIsNone(validator.validate_json())
@@ -557,15 +579,15 @@ class TestFileExtensionValidator(SixTestCase):
 
     def test_fileextensionvalidator_on_extension(self):
         validator = FileExtensionValidator(accept=[".csv"])
-        self.assertTrue(validator.is_valid('file.csv'))
-        self.assertFalse(validator.is_valid('file.tsv'))
-        self.assertFalse(validator.is_valid('file.txt'))
+        self.assertTrue(validator.is_valid("file.csv"))
+        self.assertFalse(validator.is_valid("file.tsv"))
+        self.assertFalse(validator.is_valid("file.txt"))
 
     def test_fileextensionvalidator_on_extensions(self):
         validator = FileExtensionValidator(accept=[".csv", ".pdf"])
-        self.assertTrue(validator.is_valid('file.csv'))
-        self.assertTrue(validator.is_valid('file.pdf'))
-        self.assertFalse(validator.is_valid('file.docx'))
+        self.assertTrue(validator.is_valid("file.csv"))
+        self.assertTrue(validator.is_valid("file.pdf"))
+        self.assertFalse(validator.is_valid("file.docx"))
 
         with self.assertRaises(ValueError):
             # noinspection PyTypeChecker
@@ -573,35 +595,35 @@ class TestFileExtensionValidator(SixTestCase):
 
     def test_fileextensionvalidator_on_extensions_csv(self):
         validator = FileExtensionValidator(accept=".csv,.pdf")
-        self.assertTrue(validator.is_valid('file.csv'))
-        self.assertTrue(validator.is_valid('file.pdf'))
-        self.assertFalse(validator.is_valid('file.docx'))
+        self.assertTrue(validator.is_valid("file.csv"))
+        self.assertTrue(validator.is_valid("file.pdf"))
+        self.assertFalse(validator.is_valid("file.docx"))
 
     def test_fileextensionvalidator_on_mimetype(self):
         validator = FileExtensionValidator(accept=["application/pdf"])
-        self.assertTrue(validator.is_valid('file.pdf'))
-        self.assertFalse(validator.is_valid('file.docx'))
+        self.assertTrue(validator.is_valid("file.pdf"))
+        self.assertFalse(validator.is_valid("file.docx"))
 
     def test_fileextensionvalidator_on_expanded_mimetypes(self):
         validator = FileExtensionValidator(accept=["video/*"])
-        self.assertTrue(validator.is_valid('file.mp4'))
-        self.assertTrue(validator.is_valid('file.mov'))
-        self.assertTrue(validator.is_valid('file.mpeg'))
-        self.assertTrue(validator.is_valid('file.flv'))
-        self.assertTrue(validator.is_valid('file.wmv'))
-        self.assertTrue(validator.is_valid('file.webm'))
+        self.assertTrue(validator.is_valid("file.mp4"))
+        self.assertTrue(validator.is_valid("file.mov"))
+        self.assertTrue(validator.is_valid("file.mpeg"))
+        self.assertTrue(validator.is_valid("file.flv"))
+        self.assertTrue(validator.is_valid("file.wmv"))
+        self.assertTrue(validator.is_valid("file.webm"))
 
     def test_fileextensionvalidator_on_mixed_mode(self):
         validator = FileExtensionValidator(accept=[".csv", "application/pdf"])
-        self.assertTrue(validator.is_valid('file.csv'))
-        self.assertTrue(validator.is_valid('file.pdf'))
-        self.assertFalse(validator.is_valid('file.docx'))
+        self.assertTrue(validator.is_valid("file.csv"))
+        self.assertTrue(validator.is_valid("file.pdf"))
+        self.assertFalse(validator.is_valid("file.docx"))
 
     def test_fileextensionvalidator_on_excel(self):
         validator = FileExtensionValidator(accept=[".xls", ".xlsx"])
-        self.assertTrue(validator.is_valid('file.xls'))
-        self.assertTrue(validator.is_valid('file.xlsx'))
-        self.assertFalse(validator.is_valid('file.docx'))
+        self.assertTrue(validator.is_valid("file.xls"))
+        self.assertTrue(validator.is_valid("file.xlsx"))
+        self.assertFalse(validator.is_valid("file.docx"))
 
     def test_fileextensionvalidator_being_none(self):
         validator = FileExtensionValidator(accept=["video/*"])
@@ -609,8 +631,7 @@ class TestFileExtensionValidator(SixTestCase):
         self.assertIsNone(validator.is_valid(None))
 
 
-class TestPropertyWithValidator(SixTestCase):
-
+class TestPropertyWithValidator(TestCase):
     def test_property_without_validator(self):
         prop = Property(json={}, client=None)
         self.assertIsNone(prop.is_valid)
@@ -623,7 +644,8 @@ class TestPropertyWithValidator(SixTestCase):
             value=1,
             value_options=dict(
                 validators=[NumericRangeValidator(minvalue=0, maxvalue=10).as_json()]
-            ))
+            ),
+        )
         prop = Property(json=prop_json, client=None)
         self.assertTrue(prop.is_valid)
         self.assertFalse(prop.is_invalid)
@@ -634,7 +656,8 @@ class TestPropertyWithValidator(SixTestCase):
             value=None,
             value_options=dict(
                 validators=[NumericRangeValidator(minvalue=0, maxvalue=10).as_json()]
-            ))
+            ),
+        )
         prop = Property(json=prop_json, client=None)
         self.assertIsNone(prop.is_valid)
         self.assertIsNone(prop.is_invalid)
@@ -643,9 +666,8 @@ class TestPropertyWithValidator(SixTestCase):
     def test_property_with_filesize_validator(self):
         prop_json = dict(
             value="attachments/12345678-1234-5678-1234-567812345678/some_file.txt",
-            value_options=dict(
-                validators=[FileSizeValidator(max_size=100).as_json()]
-            ))
+            value_options=dict(validators=[FileSizeValidator(max_size=100).as_json()]),
+        )
         prop = AttachmentProperty(json=prop_json, client=None)
         self.assertTrue(prop.is_valid)
         self.assertFalse(prop.is_invalid)
@@ -653,10 +675,8 @@ class TestPropertyWithValidator(SixTestCase):
 
     def test_property_without_value_with_filesize_validator(self):
         prop_json = dict(
-            value=None,
-            value_options=dict(
-                validators=[FileSizeValidator(max_size=100).as_json()]
-            ))
+            value=None, value_options=dict(validators=[FileSizeValidator(max_size=100).as_json()])
+        )
         prop = AttachmentProperty(json=prop_json, client=None)
         self.assertIsNone(prop.is_valid)
         self.assertIsNone(prop.is_invalid)
@@ -666,8 +686,9 @@ class TestPropertyWithValidator(SixTestCase):
         prop_json = dict(
             value="attachments/12345678-1234-5678-1234-567812345678/some_file.txt",
             value_options=dict(
-                validators=[FileExtensionValidator(accept=['.txt', 'application/pdf']).as_json()]
-            ))
+                validators=[FileExtensionValidator(accept=[".txt", "application/pdf"]).as_json()]
+            ),
+        )
         prop = AttachmentProperty(json=prop_json, client=None)
         self.assertTrue(prop.is_valid)
         self.assertFalse(prop.is_invalid)
@@ -677,8 +698,9 @@ class TestPropertyWithValidator(SixTestCase):
         prop_json = dict(
             value=None,
             value_options=dict(
-                validators=[FileExtensionValidator(accept=['.txt', 'application/pdf']).as_json()]
-            ))
+                validators=[FileExtensionValidator(accept=[".txt", "application/pdf"]).as_json()]
+            ),
+        )
         prop = AttachmentProperty(json=prop_json, client=None)
         self.assertIsNone(prop.is_valid)
         self.assertIsNone(prop.is_invalid)
@@ -686,20 +708,22 @@ class TestPropertyWithValidator(SixTestCase):
 
 
 class TestPropertyWithValidatorFromLiveServer(TestBetamax):
-
     def setUp(self):
-        super(TestPropertyWithValidatorFromLiveServer, self).setUp()
-        self.part_model = self.project.model(name='Model')
-        self.numeric_range_prop_model = self.part_model.add_property(name='numericrange_validatortest',
-                                                                     property_type=PropertyType.FLOAT_VALUE)
-        self.numeric_range_prop_model.validators = [NumericRangeValidator(min=0., max=42.)]
-        self.part = self.project.part(name__startswith='Catalog').add(self.part_model, name='Model Instance for tests')
-        self.numeric_range_prop_instance = self.part.property(name='numericrange_validatortest')
+        super().setUp()
+        self.part_model = self.project.model(name="Model")
+        self.numeric_range_prop_model = self.part_model.add_property(
+            name="numericrange_validatortest", property_type=PropertyType.FLOAT_VALUE
+        )
+        self.numeric_range_prop_model.validators = [NumericRangeValidator(min=0.0, max=42.0)]
+        self.part = self.project.part(name__startswith="Catalog").add(
+            self.part_model, name="Model Instance for tests"
+        )
+        self.numeric_range_prop_instance = self.part.property(name="numericrange_validatortest")
 
     def tearDown(self):
         self.numeric_range_prop_model.delete()
         self.part.delete()
-        super(TestPropertyWithValidatorFromLiveServer, self).tearDown()
+        super().tearDown()
 
     def test_numeric_property_with_validator_parses(self):
         self.assertIsInstance(self.numeric_range_prop_instance._validators, list)
@@ -719,6 +743,8 @@ class TestPropertyWithValidatorFromLiveServer(TestBetamax):
         validators = self.numeric_range_prop_instance.validators
         validators.append(RequiredFieldValidator())
 
-        with self.assertRaisesRegex(IllegalArgumentError, "To update the list of validators, it can only work "
-                                                          "on `Property` of category 'MODEL'"):
+        with self.assertRaisesRegex(
+            IllegalArgumentError,
+            "To update the list of validators, it can only work on `Property` of category 'MODEL'",
+        ):
             self.numeric_range_prop_instance.validators = validators
